@@ -4,6 +4,7 @@
 # Please indicate the source for reprinting.
 
 import os
+import platform
 
 from tkinter import messagebox
 
@@ -16,6 +17,10 @@ ICON_PATH = os.path.join(RESOURCES_PATH, "icon")
 
 HORIZONTAL = "Horizontal水平方向"
 VERTICAL = "Vertical垂直方向"
+LEFT = "左侧"
+RIGHT = "右侧"
+TOP = "顶端"
+BOTTOM = "底部"
 
 
 # Tools部分
@@ -42,10 +47,24 @@ class MessageBox:
         messagebox.showwarning(title, text)
 
     @staticmethod
-    def erroe(text: str, title: str = "错误 - QGUI"):
+    def error(text: str, title: str = "错误 - QGUI"):
         messagebox.showerror(title, text)
 
 
+def show_file_or_path(path, return_func=True):
+    def render(*args, **kwargs):
+        if platform.system().lower() == "darwin":
+            import subprocess
+            subprocess.call(["open", path])
+        else:
+            os.startfile(path)
+
+    if return_func:
+        return render
+    else:
+        return render()
+
+
 BLACK = "#24262d"
 GRAY = "#e3e3e3"
 GREEN = "#76b67e"
