@@ -11,7 +11,7 @@ from tkinter import ttk
 from tkinter import filedialog
 
 from qgui.manager import *
-from qgui.base_tools import ConcurrencyModeFlag, check_callable, ArgInfo, select_var_dtype, BaseTool
+from qgui.base_tools import ConcurrencyModeFlag, check_callable, ArgInfo, select_var_dtype, BaseTool, make_anchor
 
 RUN_ICON = os.path.join(ICON_PATH, "play_w.png")
 
@@ -150,7 +150,8 @@ class ChooseDirTextButton(BaseChooseFileTextButton):
                          button_info=button_info,
                          style=style,
                          tab_index=tab_index,
-                         async_run=async_run)
+                         async_run=async_run,
+                         mode="dir")
 
 
 class BaseButton(BaseNotebookTool):
@@ -158,11 +159,13 @@ class BaseButton(BaseNotebookTool):
                  bind_func,
                  name: str = None,
                  text: str = "开始执行",
+                 icon: str = None,
                  checked_text: str = None,
                  async_run: bool = True,
                  style: str = "primary",
                  tab_index: int = 0,
-                 concurrency_mode: bool = False):
+                 concurrency_mode: bool = False,
+                 add_width=8):
         super().__init__(bind_func,
                          name=name,
                          style=style,
@@ -171,14 +174,18 @@ class BaseButton(BaseNotebookTool):
                          concurrency_mode=concurrency_mode)
         self.text = text
         self.checked_text = checked_text
+        self.add_width = add_width
 
-        self.icon = None
+        self.icon = icon
 
     def build(self, **kwargs) -> tkinter.Frame:
         super().build(**kwargs)
         frame = ttk.Frame(self.master, style="TFrame")
         frame.pack(side="top", fill="x", padx=5, pady=5)
-        self.icon = tkinter.PhotoImage(file=RUN_ICON)
+        if self.icon:
+            self.icon = tkinter.PhotoImage(file=self.icon)
+        else:
+            self.icon = None
 
         self.text_var = tkinter.StringVar(frame, value=self.text)
 
@@ -196,10 +203,10 @@ class BaseButton(BaseNotebookTool):
         self.btn = ttk.Button(frame,
                               textvariable=self.text_var,
                               image=self.icon,
+                              width=len(self.text) + self.add_width,
                               compound='left',
                               command=self._callback(self.bind_func, click_btn, done_btn),
-                              style=self.style + "TButton",
-                              width=10)
+                              style=self.style + "TButton")
 
         self.btn.pack(anchor="ne", padx=0, pady=0)
         return frame
@@ -222,7 +229,9 @@ class RunButton(BaseButton):
                          async_run=async_run,
                          style=style,
                          tab_index=tab_index,
-                         concurrency_mode=concurrency_mode)
+                         concurrency_mode=concurrency_mode,
+                         add_width=6,
+                         icon=RUN_ICON)
 
 
 class InputBox(BaseNotebookTool):
@@ -292,7 +301,8 @@ class Combobox(BaseNotebookTool):
                                  style=self.style + "TCombobox",
                                  values=self.options)
         self.comb.current(0)
-        self.comb.bind('<<ComboboxSelected>>', self._callback(self.bind_func))
+        if self.bind_func:
+            self.comb.bind('<<ComboboxSelected>>', self._callback(self.bind_func))
         self.comb.pack(side="left", padx=5, pady=2)
 
         return frame
@@ -706,12 +716,14 @@ class BaseCombine(BaseNotebookTool):
     def __init__(self,
                  tools: BaseNotebookTool or List[BaseNotebookTool],
                  side=HORIZONTAL,
-                 title=None,
+                 title: str = None,
+                 text: str = None,
                  style: str = None,
                  tab_index: int = None):
         super().__init__(tab_index=tab_index, style=style)
         self.side = "top" if side == HORIZONTAL else "left"
         self.title = title
+        self.text = text
 
         self.tools = tools if isinstance(tools, list) else [tools]
 
@@ -737,6 +749,11 @@ class BaseFrameCombine(BaseCombine):
         else:
             frame = ttk.Frame(self.master, text=self.title, style=self.style + style_mode)
         frame.pack(side="left", anchor="nw", fill="both", expand="yes", padx=8, pady=8)
+        if self.text:
+            label = ttk.Label(frame,
+                              text=self.text,
+                              style="TLabel")
+            label.pack(side="top", anchor="nw", padx=5)
         for tool in self.tools:
             kwargs["master"] = frame
             tool.build(*args, **kwargs)
@@ -748,11 +765,13 @@ class HorizontalFrameCombine(BaseFrameCombine):
                  tools: BaseNotebookTool or List[BaseNotebookTool],
                  title=None,
                  style: str = None,
+                 text: str = None,
                  tab_index: int = 0):
         super().__init__(tools=tools,
                          side=HORIZONTAL,
                          title=title,
                          style=style,
+                         text=text,
                          tab_index=tab_index)
 
 
@@ -761,25 +780,28 @@ class VerticalFrameCombine(BaseFrameCombine):
                  tools: BaseNotebookTool or List[BaseNotebookTool],
                  title=None,
                  style: str = None,
+                 text: str = None,
                  tab_index: int = 0):
         super().__init__(tools=tools,
                          side=VERTICAL,
                          title=title,
                          style=style,
+                         text=text,
                          tab_index=tab_index)
 
 
 class HorizontalToolsCombine(BaseCombine):
     def __init__(self,
                  tools: BaseNotebookTool or List[BaseNotebookTool],
-                 side=HORIZONTAL,
                  title=None,
                  style: str = None,
+                 text: str = None,
                  tab_index: int = None):
         super().__init__(tools=tools,
-                         side=side,
+                         side=HORIZONTAL,
                          title=title,
                          style=style,
+                         text=text,
                          tab_index=tab_index)
 
     def build(self, *args, **kwargs):
@@ -790,9 +812,49 @@ class HorizontalToolsCombine(BaseCombine):
         else:
             frame = ttk.Frame(self.master, style=self.style + style_mode)
         frame.pack(side="top", fill="x", expand="yes")
+        if self.text:
+            label = ttk.Label(frame,
+                              text=self.text,
+                              style="TLabel")
+            label.pack(side="top", anchor="nw", padx=5)
         for tool in self.tools:
             sub_frame = ttk.Frame(frame, style="TFrame")
             sub_frame.pack(side="left", fill="x", expand="yes")
             kwargs["master"] = sub_frame
             tool.build(*args, **kwargs)
         return frame
+
+
+class Label(BaseNotebookTool):
+    def __init__(self,
+                 name: str = None,
+                 text: str = None,
+                 alignment: str = LEFT + TOP,
+                 style: str = "primary",
+                 tab_index: int = 0):
+        super(Label, self).__init__(name=name,
+                                    style=style,
+                                    tab_index=tab_index)
+        self.text = text
+        self.alignment = alignment
+
+        self.label_var = tkinter.StringVar(value=self.text)
+
+    def build(self, *args, **kwargs) -> tkinter.Frame:
+        super(Label, self).build(*args, **kwargs)
+        frame = ttk.Frame(self.master)
+        frame.pack(side="top", fill="both")
+        label = ttk.Label(frame,
+                          text=self.text,
+                          textvariable=self.label_var,
+                          style="TLabel")
+        # make_anchor(self.alignment)
+        label.pack(anchor=make_anchor(self.alignment),
+                   padx=DEFAULT_PAD,
+                   pady=DEFAULT_PAD)
+        return frame
+
+    def get_arg_info(self) -> ArgInfo:
+        field = self.name if self.name else self.__class__.__name__
+        local_info = ArgInfo(field, set_func=self.label_var.set, get_func=self.label_var.get)
+        return local_info
